@@ -3,6 +3,7 @@ import logging
 import subprocess
 import sys
 import time
+from types import SimpleNamespace
 from typing import Dict, List, Union, Tuple
 
 from ..log_pipe import LogPipe
@@ -21,6 +22,7 @@ class Task:
     __avail_container_tech = ['docker', 'shifter', 'singularity']
 
     def __init__(self, commands: Union[str, List[str]],
+                 env: Dict = None,
                  n_threads: int = 1,
                  container_tech: str = None,
                  container_image: str = None,
@@ -28,6 +30,7 @@ class Task:
         f"""
         Task object constructor
         :param commands: Commands to execute. Accepted formats: [str, List[str]].
+        :param env: Environment variables
         :param n_threads: Number of threads for the task.
         :param container_tech: Options are: {self.__avail_container_tech}.
         :param container_image: Name of the image to use.
@@ -43,6 +46,8 @@ class Task:
         else:
             raise Exception(f'Unknown task commands type: {type(commands)}')
 
+        self.__env = env
+
         self.__n_threads = n_threads
 
         # Containerization technology
@@ -142,7 +147,8 @@ class Task:
         if task.container_tech is None:
             pass
         elif task.container_tech == 'shifter':
-            formatted_command = f'shifter --image={task.container_image} {task.container_args} /bin/bash -c \'{formatted_command}\''
+            formatted_command = f'shifter --image={task.container_image} {task.container_args} ' \
+                                f'/bin/bash -c \'{formatted_command}\''
         else:
             raise Exception(f'Containerization technology {task.container_tech} not supported yet.')
 
@@ -155,7 +161,7 @@ class Task:
         """
         return Task.__get_command(self)
 
-    def execute(self, timeout_hour=-1) -> Tuple[int, str, str]:
+    def execute(self, timeout_hour=-1) -> SimpleNamespace:
         """
         Execute the task
         :return:
@@ -164,9 +170,12 @@ class Task:
 
         self.__logger.info(f'Starting execution of the command: {formatted_command}')
 
-        args = {}
+        kwargs = {}
         if timeout_hour > 0:
-            args['timeout'] = timeout_hour * 3600
+            kwargs['timeout'] = timeout_hour * 3600
+
+        if self.__env is not None:
+            kwargs['env'] = self.__env
 
         self.__logger.info(f'Execution starts at: {datetime.datetime.now()}')
         execution_start = time.time()
@@ -174,8 +183,9 @@ class Task:
         try:
             sys.stdout = LogPipe(self.__logger, logging.INFO)
             sys.stderr = LogPipe(self.__logger, logging.ERROR)
-            results = subprocess.run(formatted_command, shell=True, text=True, stdout=sys.stdout, stderr=sys.stderr)
-
+            results = subprocess.run(formatted_command, shell=True, text=True,
+                                     stdout=sys.stdout, stderr=sys.stderr,
+                                     **kwargs)
         finally:
             sys.stdout.close()
             sys.stderr.close()
@@ -186,11 +196,13 @@ class Task:
             sys.stdout = sys.__stdout__
             sys.stderr = sys.__stderr__
 
-        execution_time = datetime.timedelta(seconds=time.time() - execution_start)
-        self.__logger.info(f'Execution ends at: {datetime.datetime.now()} with the exit code: {results.returncode}')
-        self.__logger.info(f'Execution time: {execution_time} ({execution_time.total_seconds()} s)')
+            execution_time = datetime.timedelta(seconds=time.time() - execution_start)
 
-        return results.returncode, stdout, stderr
+            self.__logger.info(f'Execution ends at: {datetime.datetime.now()} '
+                               f'- Execution time: {execution_time} ({execution_time.total_seconds()} s)')
+            self.__logger.info(f'Exit code: {results.returncode}')
+
+        return SimpleNamespace(exit_code=results.returncode, stdout=stdout, stderr=stderr)
 
     @classmethod
     def from_dict(cls, dictionary: Dict) -> 'Task':
